pub enum UdpError {
SendError(Error),
BindError(Error),
ConnectionError(Error),
}Expand description
Custom networking (udp) errors.
Variants
SendError(Error)
This error is thrown when a message has failed to send.
BindError(Error)
This error is thrown when the [UdpSocket] has failed to bind to the local address.
ConnectionError(Error)
This error is thrown when no remote address could be resolved.